<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://plume-editor.com/
 * @since      1.0.0
 *
 * @package    Plume
 * @subpackage Plume/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plume
 * @subpackage Plume/admin
 * @author     Plume
 */
class Plume_Admin
{




    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plume_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plume_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style('sweetalert2', 'https://cdnjs.cloudflare.com/ajax/libs/limonte-sweetalert2/11.4.17/sweetalert2.min.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/plume-admin.css', array(), $this->version, 'all');
        wp_enqueue_style('flatpickr', 'https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css', array(), $this->version, 'all');
        wp_enqueue_style('flatpickr-dark', 'https://cdn.jsdelivr.net/npm/flatpickr/dist/themes/dark.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plume_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plume_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/plume-admin.js', array('jquery'), $this->version, true);
        $options = get_option('plume_options');

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');
        $api = new PlumeApi();
        $prices = json_decode($api->call_api('textbulker_prices', []));
        $langs = json_decode($api->call_api('textbulker_languages_list', []));

        $translation_array = array(
            'api_key' => $options['api_key'],
            'texbulker_prices' => json_encode($prices->prices),
            'texbulker_langs' => json_encode($langs->lang),
        );
        wp_localize_script($this->plugin_name, 'plumedata', $translation_array);

//        wp_enqueue_script('sweetalert2', 'https://cdnjs.cloudflare.com/ajax/libs/limonte-sweetalert2/11.4.17/sweetalert2.min.js', array('jquery'), $this->version, false);
        wp_enqueue_script('sweetalert2', 'https://cdn.jsdelivr.net/npm/sweetalert2@11', array('jquery'), $this->version, false);
        wp_enqueue_script('flatpickr-fr', 'https://cdn.jsdelivr.net/npm/flatpickr/dist/l10n/fr.js', array('jquery'), $this->version, false);
        wp_enqueue_script('flatpickr', 'https://cdn.jsdelivr.net/npm/flatpickr', array('jquery'), $this->version, false);
        
    }

    public function plugin_loaded()
    {

        require_once(PLUME_PLUGIN_PATH . 'includes/class-plume-activator.php');
        add_action('plugins_loaded', array('Plume_Activator', 'get_instance'));

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-admin-settings.php');
        add_action('plugins_loaded', array('PlumeAdminSettings', 'get_instance'));

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-admin-menu.php');
        add_action('plugins_loaded', array('PlumeAdminMenu', 'get_instance'));

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-admin-ajax.php');
        add_action('plugins_loaded', array('PlumeAdminAjax', 'get_instance'));

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-admin-notice.php');
        add_action('plugins_loaded', array('PlumeAdminNotice', 'get_instance'));

        require_once PLUME_PLUGIN_PATH .  'admin/classes/class-plume-posts-transition.php';
        add_action('plugins_loaded', array('PlumePostsTransition', 'get_instance'));
    }

}