<?php


class PlumeAdminAjax
{
    // class instance
    protected static $instance;


    private $options;
    private $api;
    private $plume_folders;

    public function __construct()
    {
        add_action('wp_ajax_plumepreorder', [$this, 'pre_order']);
        add_action('wp_ajax_plumeredownload', [$this, 're_download']);
        add_action('wp_ajax_plumepurchase', [$this, 'purchase']);
        add_action('wp_ajax_plumereserve', [$this, 'reserve']);
        add_action('wp_ajax_plumepurchasebulk', [$this, 'purchase_bulk']);
        add_action('wp_ajax_plumedownloadbulk', [$this, 'download_bulk']);
        add_action('wp_ajax_plumereservebulk', [$this, 'reserve_bulk']);
        add_action('wp_ajax_plumeexamination', [$this, 'examination']);
        add_action('wp_ajax_plumefolders', [$this, 'get_folders']);
        add_action('wp_ajax_plumeaddfolder', [$this, 'add_folder']);
        add_action('wp_ajax_plumeremovefolder', [$this, 'remove_folder']);
        add_action('wp_ajax_plumeremovearticle', [$this, 'remove_article']);
        add_action('wp_ajax_plumemovearticlesbulk', [$this, 'move_articles_to_folder']);
        add_action('wp_ajax_plumetextbulkerprices', [$this, 'get_textbulker_prices']);
        add_action('wp_ajax_plumetextbulkerlanguages', [$this, 'get_textbulker_languages']);

        $this->options = get_option('plume_options');
        $this->api_key = $this->options['api_key'];

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');
        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-folders.php');
        $this->api = new PlumeApi();
        $this->plume_folders = new PlumeFolders();
    }

    /** Singleton instance */
    public static function get_instance()
    {
        if (!isset(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    function render_response($response)
    {
        header("Content-Type: application/json");
        echo $response;
        exit();
    }

    function pre_order()
    {
        switch ($_POST['type']) {
            case 'textbulker':
                $endpoint = 'add_textbulker_project';
                $data = [
                    'keywords' => wp_kses_post($_POST['keywords']),
                    'brief' => wp_kses_post($_POST['brief']),
                    'verify' => $_POST['verify'] == 'true',
                    'lang' => sanitize_text_field($_POST['lang']),
                ];
                $response = $this->api->call_api_post($endpoint, $data);
                break;
            default :
                $endpoint = 'preorder_posts';
                $data = [
                    'posttitle' => sanitize_text_field($_POST['posttitle']),
                    'wordcount' => intval($_POST['wordcount']),
                    'brief' => wp_kses_post($_POST['brief']),
                    'articlecount' => intval($_POST['articlecount'])
                ];
                $response = $this->api->call_api($endpoint, $data);
                break;
        }


        $this->render_response($response);
    }

    function re_download()
    {
        // check post is not already published
        $article_id = intval($_POST['article_id']);
        $endpoint = 'can_publish_posts';
        $data = [
            "article_ids" => [$article_id]
        ];
        $response = $this->api->call_api($endpoint, $data);
        $response = json_decode($response);
        if ($response->status !== 'success') {
            $message = sprintf('L\'article est déjà publié <a href="%1$s" target="_blank">ici</a>.<br>Veuillez le dépublier avant de le télécharger sur ce site.',$response->data[0]->permalink);
            $response->message = $message;
            $this->render_response(json_encode($response));
        }

        $response = $this->call_redownload_posts($article_id);
        $response = json_decode($response);
        $this->options = get_option('plume_options');
        if($response->status == 'success') {
            $post_id = $this->insert_post_with_images($response->data->title, $response->data->post_content, $this->options['author'], $this->options['category'], $response->data->article_purchase_id, $publish_date);

            $this->call_update_article($response->data->article_purchase_id, $post_id);
            $this->attach_image_to_post($post_id, $response->data->image);
        }

        $this->render_response(json_encode($response));
    }

    function examination()
    {
        $endpoint = 'examine_posts';
        $data = [
            'article_id' => $_POST['article_id'],
            'message' =>wp_kses_post($_POST['message']),
        ];
        $response = $this->api->call_api($endpoint, $data);
        $this->render_response($response);
    }

    function reserve_bulk()
    {
        $responses = [];
        foreach ($_POST['article_ids'] as $article_id) {
            $endpoint = 'reserve_posts';
            $data = [
                'post_id' => intval($article_id),
            ];
            $responses[] = json_decode($this->api->call_api($endpoint, $data));
        }

        $this->render_response(json_encode($this->prepare_response($responses)));
    }

    function download_bulk()
    {
        $this->options = get_option('plume_options');
        $endpoint = 'can_publish_posts';
        $data = [
            "article_ids" => $_POST['article_ids']
        ];
        $response = $this->api->call_api($endpoint, $data);

        $response = json_decode($response);

        if ($response->status !== 'success') {
            $message = sprintf('%d article(s) est(sont) déjà publié(s).<br>Veuillez le(s) dépublier avant de le(s) télécharger sur ce site.', count($response->data));
            $response->message = $message;
            $this->render_response(json_encode($response));
        }

        $responses = [];
        foreach ($_POST['article_ids'] as $article_id) {
            $response = $this->call_redownload_posts($article_id);
            $responses[] = $response = json_decode($response);
            if ($response->status == 'success') {
                $post_id = $this->insert_post_with_images($response->data->title, $response->data->post_content, $this->options['author'], $this->options['category'], $response->data->article_purchase_id);
                $this->call_update_article($response->data->article_purchase_id, $post_id);
                $this->attach_image_to_post($post_id, $response->data->image);
            }

        }
        $this->render_response(json_encode($this->prepare_response($responses)));
    }

    function purchase_bulk()
    {
        $responses = [];
        $publish_date = $_POST['publish_date'];
        foreach ($_POST['article_ids'] as $article_id) {
            $response = $this->call_purchase_posts($article_id);
            $responses[] = $response = json_decode( $response);
            if ($response->status == 'success') {
                //$post_id = $this->insert_post_with_images($response->data->title, $response->data->post_content, $_POST['user_id'], $_POST['category_id'], $response->data->article_purchase_id);
                //$post_id = $this->insert_post_with_images($response->data->title, $response->data->post_content, $_POST['user_id'], $_POST['category_id'], $response->data->article_purchase_id, $_POST['publish_date']);
                $post_id = $this->insert_post_with_images($response->data->title, $response->data->post_content, $_POST['user_id'], $_POST['category_id'], $response->data->article_purchase_id, $publish_date);
                $publish_date = date("Y-m-d H:i:s", strtotime($publish_date . ' +1 day'));
                $this->call_update_article($response->data->article_purchase_id, $post_id);
                $this->attach_image_to_post($post_id, $response->data->image);
            }
        }

        return $this->render_response(json_encode($this->prepare_response($responses)));
    }

    function prepare_response($responses) {
        $result = (object)[
            'status' => "success",
            'message' => ""
        ];
        foreach ($responses as $response){
            if($response->status != 'success'){
                $result->status = $response->status;
                $result->message .= $response->message . '<br/>';
            }
        }
        return $result;
    }

    function reserve()
    {
        $endpoint = 'reserve_posts';
        $data = [
            'post_id' => $_POST['article_id'],
            'website' => get_site_url()
        ];
        $response = $this->api->call_api($endpoint, $data);
        $this->render_response($response);
    }

    function purchase()
    {
        $response = $this->call_purchase_posts($_POST['article_id']);
        $response = json_decode($response);
        if($response->status == 'success') {
            $post_content = $response->data->post_content;
            //$post_id = $this->insert_post_with_images($response->data->title, $post_content, $_POST['user_id'], $_POST['category_id'], $_POST['publish_post'], $_POST['publish_date'], $response->data->article_purchase_id);
            //$post_id = $this->insert_post_with_images($response->data->title, $post_content, $_POST['user_id'], $_POST['category_id'], $_POST['publish_date'], $response->data->article_purchase_id);
            $post_id = $this->insert_post_with_images($response->data->title, $post_content, $_POST['user_id'], $_POST['category_id'], $response->data->article_purchase_id, $_POST['publish_date']);

            $this->call_update_article($response->data->article_purchase_id, $post_id);
            $this->attach_image_to_post($post_id, $response->data->image);
        }
        $this->render_response(json_encode($response));
    }

    function call_redownload_posts($article_id)
    {
        $endpoint = 'redownload_posts';
        $data = [
            'article_id' => intval($article_id),
        ];
        return $this->api->call_api($endpoint, $data);

    }

    function call_purchase_posts($article_id)
    {
        $endpoint = 'purchase_posts';
        $data = [
            'post_id' => intval($article_id),
            'website' => get_site_url()
        ];
        return $this->api->call_api($endpoint, $data);
    }

    function call_update_article($article_purchase_id, $client_post_id)
    {
        $endpoint = 'update_article';
        $data = [
            'article_purchase_id' => $article_purchase_id,
            'client_post_id' => $client_post_id,
        ];
        $this->api->call_api($endpoint, $data);
    }

    //function insert_post_with_images($post_title, $post_content, $author_id, $category_id, $article_purchase_id, $publish_post, $publish_date)
    function insert_post_with_images($post_title, $post_content, $author_id, $category_id, $article_purchase_id, $publish_date)
    {
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        $doc = new DOMDocument();
        libxml_use_internal_errors(true);
        $doc->loadHTML($post_content);
        $xpath = new DOMXPath($doc);
        $imgs = $xpath->query("//img");
        for ($i = 0; $i < $imgs->length; $i++) {
            $img = $imgs->item($i);
            $post_image_url = $img->getAttribute("src");
            $upload_dir = wp_upload_dir();

            $image_data = file_get_contents($post_image_url);

            $filename = basename($post_image_url);

            if (wp_mkdir_p($upload_dir['path'])) {
                $file = $upload_dir['path'] . '/' . $filename;
            } else {
                $file = $upload_dir['basedir'] . '/' . $filename;
            }

            file_put_contents($file, $image_data);

            $wp_filetype = wp_check_filetype($filename, null);

            $attachment = array(
                'post_mime_type' => $wp_filetype['type'],
                'post_title' => sanitize_file_name($filename),
                'post_content' => '',
                'post_status' => 'inherit'
            );

            $attach_id = wp_insert_attachment($attachment, $file);

            $attach_data = wp_generate_attachment_metadata($attach_id, $file);
            wp_update_attachment_metadata($attach_id, $attach_data);
            $newimage = wp_get_attachment_url($attach_id);
            $post_content = str_replace($post_image_url, $newimage, $post_content);
        }
        
        if (!empty($publish_date)) {
            $post_status = 'future';
        } else {
            $post_status = 'draft';
        }

        //$post_status = $publish_post ? 'publish' : 'draft';
        $new_post = array(
            'post_title' => $post_title,
            'post_content' => $post_content,
            'post_status' => $post_status,
            'post_date' => !empty($publish_date) ? $publish_date : date('Y-m-d H:i:s'),
            'post_author' => $author_id,
            'post_type' => 'post',
            'post_category' => array($category_id)
        );
        $post_id = wp_insert_post($new_post);
        update_post_meta($post_id, 'article_purchase_id', $article_purchase_id);
        return $post_id;
    }

    function attach_image_to_post($post_id, $image_url)
    {
        if ($post_id && $image_url) {
            $exploded = explode('/', $image_url);

            $image_name = end($exploded);
            $upload_dir = wp_upload_dir(); // Set upload folder
            $image_data = file_get_contents($image_url); // Get image data
            $unique_file_name = wp_unique_filename($upload_dir['path'], $image_name); // Generate unique name
            $filename = basename($unique_file_name); // Create image file name

            // Check folder permission and define file location
            if (wp_mkdir_p($upload_dir['path'])) {
                $file = $upload_dir['path'] . '/' . $filename;
            } else {
                $file = $upload_dir['basedir'] . '/' . $filename;
            }

            // Create the image  file on the server
            file_put_contents($file, $image_data);

            // Check image file type
            $wp_filetype = wp_check_filetype($filename, null);

            // Set attachment data
            $attachment = array(
                'post_mime_type' => $wp_filetype['type'],
                'post_title' => sanitize_file_name($filename),
                'post_content' => '',
                'post_status' => 'inherit'
            );

            // Create the attachment
            $attach_id = wp_insert_attachment($attachment, $file, $post_id);

            // Include image.php
            require_once(ABSPATH . 'wp-admin/includes/image.php');

            // Define attachment metadata
            $attach_data = wp_generate_attachment_metadata($attach_id, $file);

            // Assign metadata to attachment
            wp_update_attachment_metadata($attach_id, $attach_data);

            // And finally assign featured image to post
            set_post_thumbnail($post_id, $attach_id);
        }
    }

    function get_folders()
    {
        $this->render_response($this->plume_folders->get_folders());
    }

    function add_folder()
    {
        $folder_name = sanitize_text_field($_POST['folder_name']);
        $this->render_response($this->plume_folders->add_folder($folder_name));
    }

    function remove_folder()
    {
        $folder_id = sanitize_text_field($_POST['folder_id']);
        $this->render_response($this->plume_folders->remove_folder($folder_id));
    }

    function remove_article()
    {
        $article_id = intval($_POST['article_id']);
        $this->render_response($this->plume_folders->remove_article_from_folder($article_id));
    }

    function move_articles_to_folder()
    {
        $folder_id = sanitize_text_field($_POST['folder_id']);
        $article_ids = $_POST['article_ids'];

        $this->render_response($this->plume_folders->move_articles($folder_id, $article_ids));
    }
    function get_textbulker_prices() {
        $endpoint = 'textbulker_prices';
        $data = [];
        $response = $this->api->call_api($endpoint, $data);
        $this->render_response($response);

    }
    function get_textbulker_languages() {
        $endpoint = 'textbulker_languages_list';
        $data = [];
        $response = $this->api->call_api($endpoint, $data);
        $this->render_response($response);

    }
}
