<?php

class PlumeAdminMenu
{
    // class instance
    protected static $instance;

    public function __construct()
    {

        add_action('admin_menu', array($this, 'admin_menu'));

        add_filter('manage_edit-wallet_tansferts_columns', [$this, 'column_headers']);
        add_filter('manage_wallet_tansferts_posts_custom_column', [$this, 'column_data'], 1, 2);
    }

    /** Singleton instance */
    public static function get_instance()
    {
        if (!isset(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    public function admin_menu()
    {
        add_menu_page(
            __('Plume', 'plume'),
            __('Plume', 'plume'),
            'manage_options',
            'plume',
            [$this, 'admin_page_contents'],
            PLUME_PLUGIN_URL . 'admin/img/plume-ico.svg',
            3
        );
        add_submenu_page("plume", "Purchased", "Mes articles", "manage_options", "plume-purchased", [$this, 'purchased']);
        add_submenu_page("plume", "Settings", "Paramètres", "manage_options", "plume-api-settings", [$this, 'settings_page']);
        add_options_page('plume', 'Plume Settings', 'manage_options', 'plume-settings', [$this, 'settings_page']);

    }

    public function admin_page_contents()
    {
        $options = get_option('plume_options');
        if (!$options['plume_version_ok']) {
            return;
        }
        $table = new PlumeListTable();
        $table->prepare_items();
        $args_author = array(
            "name" => "plume_author",
            "selected" => $options['author']
        );
        $args_category = array(
            "name" => "plume_category",
            "selected" => $options['category'],
            'hide_empty' => false
        );
        ?>
        <div class="wrap">
            <h2><img src="https://plume-editor.com/plume.svg"> <?php _e('Le Catalogue', 'plume') ?>

                <button id="plume-preorder" class="page-title-action" type="button"><img src="https://plume-editor.com/wp-content/uploads/2022/12/editer-1.png">Commande</button>

            </h2>
            <div id="plumepopupdata" style='display:none'>
                <table class="plume-down-options">
                    <thead>
                    <tr>
                        <th colspan="2">Options</th>
                    </tr>
                    </thead>
                    <tr>
                        <td>Auteur :</td>
                        <td><?php wp_dropdown_users($args_author); ?></td>
                    </tr>
                    <tr>
                        <td>Catégorie :</td>
                        <td><?php wp_dropdown_categories($args_category); ?></td>
                    </tr>
                    <tr>
                        <th colspan="2">Facultatif</th>
                        </tr>
                    <tr>
                    <td>Date de publication :</td>
                            <td>
                                <input type="text" id="plume_publish_date" class="plume-datepicker" placeholder="Date de publication">
                            </td>
                    </tr>
                </table>
            </div>

            
            


            <div id="plumepopupdatabulk" style='display:none'>
                <table class="plume-down-options">
                    <thead>
                        <tr>
                            <th colspan="2">Options</th>
                        </tr>
                        </thead>
                        <tr>
                            <td>Auteur :</td>
                            <td><?php wp_dropdown_users($args_author); ?></td>
                        </tr>
                        <tr>
                            <td>Catégorie :</td>
                            <td><?php wp_dropdown_categories($args_category); ?></td>
                        </tr>
                        <tr>
                            <th colspan="2">Facultatif</th>
                        </tr>
                        <tr>
                            <td>Date de publication :</td>
                            <td>
                                <input type="text" id="plume_publish_date" class="plume-datepicker" placeholder="Date de début">
                            </td>
                        </tr>
                </table>
            </div>

            


            <?php
            $urlall = admin_url("admin.php?page=plume");
            $urlprepurchase = admin_url("admin.php?page=plume&type=prepurchase");

            $urlpurchased = admin_url("admin.php?page=plume-purchased");
            $search_text = '';
            if (!isset($_REQUEST['type']) || empty($_REQUEST['type'])) {
                $search_text = ' dans Disponibles';
            }
            if (isset($_REQUEST['type']) && !empty($_REQUEST['type'])) {
                $search_text = ' dans À Réserver';
            }
            if (isset($_REQUEST['type']))
            ?>
            <form id="plume-table" method="POST" action="<?=admin_url()?>?page=<?=$_REQUEST['page']?>">
                <input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>"/>
                <ul class="subsubsub">
                    <li class="available"><a href="<?php echo $urlall ?>"
                                             class="<?php echo empty($_REQUEST['type']) ? "current" : "" ?> "
                                             aria-current="page">Disponibles </a> |
                    </li>
                    <li class="prepurchase"><a href="<?php echo $urlprepurchase ?>" aria-current="page"
                                               class="<?php echo !empty($_REQUEST['type']) ? "current" : "" ?> ">À
                            Réserver </a>
                        |
                    </li>
                    <li class="purchased"><a href="<?php echo $urlpurchased ?>">Mes articles</a></li>
                </ul>
                <?php $table->search_box('Rechercher' . $search_text, 'search_id'); ?>
                <?php $table->display() ?>
            </form>
        </div>

    <?php
    }

    public function purchased()
    {
        $table = new PlumePurchaseTable();
        $table->prepare_items();

        $options = get_option('plume_options');
        if (!$options['plume_version_ok']) {
            return;
        }
        ?>
        <div class="wrap">
            <h2><img src="https://plume-editor.com/plume.svg"> <?php _e('Mes articles', 'plume') ?>
                <?php
                if ($options['api_key']) {
                    ?>
                    <button id="plume-preorder" class="page-title-action" type="button"><img src="https://plume-editor.com/wp-content/uploads/2022/12/editer-1.png">Commande</button>
                    <?php
                }
                ?>
            </h2>
            <?php
            $urlall = admin_url("admin.php?page=plume");
            $urlpurchased = admin_url("admin.php?page=plume-purchased");
            $urlprepurchase = admin_url("admin.php?page=plume&type=prepurchase");

            ?>
            <form id="persons-table" method="GET">
                <input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>"/>

                <ul class="subsubsub">
                    <li class="available"><a href="<?php echo $urlall ?>">Disponibles </a> |</li>
                    <li class="prepurchase"><a href="<?php echo $urlprepurchase ?>" aria-current="page">À Réserver </a>
                        |
                    </li>
                    <li class="purchased"><a href="<?php echo $urlpurchased ?>" class="current" aria-current="page">Mes
                            articles</a></li>
                </ul>
                <?php $table->display() ?>
            </form>
        </div>
        <?php
    }

    public function settings_page()
    {
        ?>
        <h2><img src="https://plume-editor.com/plume.svg"> Settings</h2>
        <form action="options.php" method="post">
            <?php
            settings_fields('plume_options');
            do_settings_sections('plume'); ?>
            <input name="submit" class="button button-primary" type="submit"
                   value="<?php esc_attr_e('Sauvegarder'); ?>"/>
        </form>
        <?php
    }
    
}