<?php

class PlumeAdminNotice
{
    private $notice_name;
    private static $instance;
    public function __construct(){
        add_action( 'admin_notices', [$this,'display_flash_notices'] );
        add_action( 'admin_notices', [$this,'check_plugin'] );

        add_action( 'add_plume_admin_notice', [$this,'add_flash_notice'],10,3 );
        $this->notice_name = 'plume_flash_notices';
    }
    public static function get_instance() {
        if ( ! isset( self::$instance ) ) {
            self::$instance = new self();
        }

        return self::$instance;
    }
    public function check_plugin()
    {
        $options = get_option('plume_options');
        if (isset($options['api_key'])) {
            require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');
            $api = new PlumeApi();
            $endpoint = 'get_client_version';
            $response = $api->call_api($endpoint,[]);
            if ($response) {
                $resobj = json_decode($response);
                if($resobj->version && version_compare(PLUME_VERSION,$resobj->version) < 0 ) {
                    $message = "<p><strong>Plume plugin error:</strong> Please update Plume plugin</p>";
                    $this->add_flash_notice($message, 'error', true);
                    $options['plume_version_ok'] = false;
                }else{
                    $options['plume_version_ok'] = true;
                }
                update_option('plume_options', $options);
            } else {
                $message =  "<p><strong>Plume plugin error:</strong> Plume plugin could not connect to the server.</p>";
                $this->add_flash_notice($message, 'error', true);
            }

        }
    }

    function add_flash_notice($notice = "", $type = "warning", $dismissible = true)
    {
        $notices = get_option($this->notice_name, array());
        if(!empty($notices)) {
            foreach ($notices as $item) {
                if (str_contains($item['notice'], $notice)) return;
            }
        }
        $dismissible_text = ($dismissible) ? "is-dismissible" : "";

        // We add our new notice.
        $notices[] = array(
            "notice" => $notice,
            "type" => $type,
            "dismissible" => $dismissible_text
        );

        // Then we update the option with our notices array
        update_option($this->notice_name, $notices);
    }

    /**
     * Function executed when the 'admin_notices' action is called, here we check if there are notices on
     * our database and display them, after that, we remove the option to prevent notices being displayed forever.
     * @return void
     */

    function display_flash_notices()
    {
        $notices = get_option($this->notice_name, array());
        // Iterate through our notices to be displayed and print them.
        foreach ($notices as $notice) {
            printf('<div class="notice notice-%1$s %2$s"><p>%3$s</p></div>',
                $notice['type'],
                $notice['dismissible'],
                $notice['notice']
            );
        }

        // Now we reset our options to prevent notices being displayed forever.
        if (!empty($notices)) {
            delete_option($this->notice_name, array());
        }
    }
}
