<?php

class PlumeAdminSettings
{
    // class instance
    protected static $instance;


    public function __construct()
    {

        add_action('admin_init', [$this, 'register_settings']);
        add_filter("plugin_action_links_".PLUME_PLUGIN_NAME, [$this, 'settings_link']);
    }

    /** Singleton instance */
    public static function get_instance()
    {
        if (!isset(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }
    function settings_link($links)
    {
        $url = admin_url("admin.php?page=plume-settings");
        $settings_link = "<a href='$url'>Settings</a>";
        array_unshift($links, $settings_link);
        return $links;
    }
    function register_settings()
    {
        register_setting('plume_options', 'plume_options', [$this, 'plume_options_validate']);
        add_settings_section('api_settings', 'API Settings', [$this, 'plume_section_text_api'], 'plume');
        add_settings_section('plume_settings', 'Paramètres', [$this, 'plume_section_text_parameters'], 'plume');


        add_settings_field('plume_setting_api_key', 'Plume API Key', [$this, 'plume_setting_api_key'], 'plume', 'api_settings');
        add_settings_field('plume_setting_api_credits', 'Crédits disponibles', [$this, 'plume_setting_api_credits'], 'plume', 'api_settings');
        add_settings_field('plume_setting_author', 'Auteur par défaut', [$this, 'plume_setting_author'], 'plume', 'plume_settings');
        add_settings_field('plume_setting_category', 'Catégorie par défaut', [$this, 'plume_setting_category'], 'plume', 'plume_settings');
    }
    function plume_options_validate($input)
    {
        $input['api_key'] = sanitize_text_field($input['api_key']);
        $input['api_credits'] = sanitize_text_field($input['api_credits']);
        $input['author'] = sanitize_text_field($input['author']);
        $input['category'] = sanitize_text_field($input['category']);

        return $input;
    }

    function plume_section_text_api()
    {
        echo '<p>Ici, vous pouvez d&eacute;finir toutes les options d\'utilisation de l\'API.<br />Vous n\'avez pas encore de Cl&eacute; API ? <strong><a href="https://plume-editor.com/" target="_blank">Rendez-vous sur Plume</a></strong> pour obtenir la v&ocirc;tre.</p>';
    }

    function plume_setting_api_key()
    {
        $options = get_option('plume_options');
        echo "<input id='plume_setting_api_key' name='plume_options[api_key]' type='text' value='" . esc_attr($options['api_key']) . "' />";
    }

    function plume_section_text_parameters()
    {
        echo '<p>Ici, vous pouvez d&eacute;finir les comportements par d&eacute;faut de vos t&eacute;l&eacute;chargements.</p>';
    }

    function plume_setting_author()
    {
        $options = get_option('plume_options');
        $args = array(
            "name" => "plume_options[author]",
            "selected" => $options['author']
        );
        wp_dropdown_users($args);
    }

    function plume_setting_category()
    {
        $options = get_option('plume_options');
        $args = array(
            "name" => "plume_options[category]",
            "selected" => $options['category'],
            'hide_empty' => false
        );
        wp_dropdown_categories($args);
    }

    function plume_setting_api_credits()
    {

        $options = get_option('plume_options');
        if (isset($options['api_key'])) {
            require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');
            $api = new PlumeApi();
            $endpoint = 'getcredits';
            $data = [
                'apikey' => $options['api_key'],
                'website' => get_site_url(),
            ];
            $response = $api->call_api($endpoint, $data);

            $resobj = json_decode($response);
            if ($resobj->status == "success") {
                echo "<input id='plume_setting_api_credits' name='plume_options[api_credits]' type='text' value='" . $resobj->totalcoins . "' readonly/><p><a href='https://plume-editor.com/mon-compte/' target='_blank'>Acheter des cr&eacute;dits</a></p>";
            } else {
                echo "<input id='plume_setting_api_credits' name='plume_options[api_credits]' type='text' value='$resobj->message' readonly/>";
            }

        }
    }
}
