<?php
require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');

class PlumeListTable extends WP_List_Table
{
    /**
     * [REQUIRED] You must declare constructor and give some basic params
     */
    function __construct()
    {
        global $status, $page, $credits;

        parent::__construct(array(
            'singular' => 'plumearticle',
            'plural' => 'plumearticles',
        ));
    }

    /**
     * [REQUIRED] this is a default column renderer
     *
     * @param $item - row (key, value array)
     * @param $column_name - string (key)
     * @return HTML
     */
    function column_default($item, $column_name)
    {
        return $item[$column_name];
    }

    function column_title($item)
    {
        $actions = array();
        if ($item['status'] == "publish") {


            $actions['edit'] = sprintf(
                '<a href="javascript:void" data-credits="%1$s"  data-id="%3$s" class="buyarticle">%2$s</a>',

                $item['credits'],
                _x('Télécharger', 'List table row action', 'wp-list-table-plume'),
                $item['id']
            );

        } else if ($item['status'] == "a-publier") {


            $actions['edit'] = sprintf(
                '<a href="javascript:void" data-credits="%1$s"  data-id="%3$s" class="reservearticle">%2$s</a>',

                $item['credits'],
                _x('Réserver', 'List table row action', 'wp-list-table-plume'),
                $item['id']
            );

        } else {
            $actions['edit'] = "<a href='javascript:void' style='color: red;'>Sold Out</a>";
        }

        return sprintf('%1$s %2$s',
            $item['title'],
            $this->row_actions($actions)
        );
    }

    /**
     * [REQUIRED] this is how checkbox column renders
     *
     * @param $item - row (key, value array)
     * @return HTML
     */
    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="id[]" value="%s" data-credits="%2$s"/>',
            $item['id'],
            $item['credits']
        );
    }

    /**
     * [REQUIRED] This method return columns to display in table
     * you can skip columns that you do not want to show
     * like content, or description
     *
     * @return array
     */
    function get_columns()
    {
        $columns = array(
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'title' => __('Titre', 'plume'),
            'image' => __('Image', 'plume'),
            'category' => __('Catégorie', 'plume'),
            'word_count' => __('Mots', 'plume'),
            'textguru' => __('YourText Guru', 'plume'),
            'anti' => __('Anti-Plagiat', 'plume'),
            'amazon' => __('Amazon', 'plume'),
			'ia' => __('Source', 'plume'),
            'lang' => __('Langue', 'plume'),
            'credits' => __('Prix', 'plume'),
        );
        return $columns;
    }

    function column_image($item)
    {
        return sprintf(
            '<img class="plume-img-table" src="%s" width="50px" height="50px"/>',
            $item['image']
        );
    }

    function column_credits($item)
    {
        global $credits;
        if ($credits < $item['credits']) {
            return sprintf(
                '<span class="credit-unavailable">%s€</span>',
                $item['credits']
            );
        }
        return sprintf(
            '<span class="credit-available">%s€</span>',
            $item['credits']
        );
    }

    function column_textguru($item)
    {
        return ($item['textguru'] ? '<img src="https://plume-editor.com/wp-content/uploads/2022/06/ytg-true.png">' : '<img src="https://plume-editor.com/wp-content/uploads/2022/06/ytg-false.png">');
    }

    function column_anti($item)
    {
        return ($item['anti'] ? '<img src="https://plume-editor.com/wp-content/uploads/2022/06/copyscape-true.png">' : '<img src="https://plume-editor.com/wp-content/uploads/2022/06/copyscape-false.png">');
    }

    function column_amazon($item)
    {
        return ($item['amazon'] ? '<img src="https://plume-editor.com/wp-content/uploads/2022/06/amazon-true.png">' : '<img src="https://plume-editor.com/wp-content/uploads/2022/06/amazon-false.png">');
    }

    function column_ia($item)
    {
		if(isset($item['textbulker'] ) && $item['textbulker'] === 1){
			return '<img title="TextBulker" src="https://plume-editor.com/wp-content/uploads/2023/01/textbulker.png">';
		}
		if($item['ia'] === 1) {
			return '<img title="Optimized hybrid" src="https://plume-editor.com/wp-content/uploads/2023/01/hybride-opti-textbulker-ytg.png" width="32px">';
		}
		return '<img title="Humain" src="https://plume-editor.com/wp-content/uploads/2022/12/blogger.png">';
    }
	function column_lang($item)
    {
		// print_r($item);
		$lang = empty($item['lang']) ? 'fr' : $item['lang'] ;
        return '<img src="https://plume-editor.com/wp-content/uploads/2023/01/lang-'.$lang.'-50x50.png" width="30px">';
    }

    /**
     * [OPTIONAL] This method return columns that may be used to sort table
     * all strings in array - is column names
     * notice that true on name column means that its default sort
     *
     * @return array
     */
    function get_sortable_columns()
    {
        $sortable_columns = array();
        return $sortable_columns;
    }

    /**
     * [OPTIONAL] Return array of bult actions if has any
     *
     * @return array
     */
    function get_bulk_actions()
    {
        $actions = array();
        if (isset($_GET['type'])) {
            $actions = array(
                'prepurchase' => 'Réserver'
            );
        } else {
            $actions = array(
                'buy' => 'Télécharger'
            );

        }

        return $actions;
    }

    /**
     * [OPTIONAL] This method processes bulk actions
     * it can be outside of class
     * it can not use wp_redirect coz there is output already
     * in this example we are processing delete action
     * message about successful deletion will be shown on page in next part
     */
    function process_bulk_action()
    {

        if ('buy' === $this->current_action()) {
            $ids = isset($_REQUEST['id']) ? $_REQUEST['id'] : array();
            if (is_array($ids)) {
                for ($i = 0; $i < count($ids); $i++) {
                    $this->purchase_posts($ids[$i]);
                }
            }
        }
    }

    function purchase_posts($postid)
    {
        $options = get_option('plume_options');
        $endpoint = 'purchase_posts';
        $data = [
            "post_id" => $postid,
        ];

        $api = new PlumeApi();
        $response = $api->call_api($endpoint, $data);
        $resppurchase = json_decode($response);

        $post_content = $resppurchase->data->post_content;

        $doc = new DOMDocument();
        libxml_use_internal_errors(true);
        $doc->loadHTML($post_content);
        $xpath = new DOMXPath($doc);
        $imgs = $xpath->query("//img");
        for ($i = 0; $i < $imgs->length; $i++) {
            $img = $imgs->item($i);
            $post_image_url = $img->getAttribute("src");
            $upload_dir = wp_upload_dir();

            $image_data = file_get_contents($post_image_url);

            $filename = basename($post_image_url);

            if (wp_mkdir_p($upload_dir['path'])) {
                $file = $upload_dir['path'] . '/' . $filename;
            } else {
                $file = $upload_dir['basedir'] . '/' . $filename;
            }

            file_put_contents($file, $image_data);

            $wp_filetype = wp_check_filetype($filename, null);

            $attachment = array(
                'post_mime_type' => $wp_filetype['type'],
                'post_title' => sanitize_file_name($filename),
                'post_content' => '',
                'post_status' => 'inherit'
            );

            $attach_id = wp_insert_attachment($attachment, $file);
            require_once(ABSPATH . 'wp-admin/includes/image.php');
            $attach_data = wp_generate_attachment_metadata($attach_id, $file);
            wp_update_attachment_metadata($attach_id, $attach_data);
            $newimage = wp_get_attachment_url($attach_id);
            $post_content = str_replace($post_image_url, $newimage, $post_content);

        }

        global $user_ID;
        $new_post = array(
            'post_title' => $resppurchase->data->title,
            'post_content' => $post_content,
            'post_status' => 'draft',
            'post_date' => date('Y-m-d H:i:s'),
            'post_author' => $user_ID,
            'post_type' => 'post',
            'post_category' => array(0)
        );
        $post_id = wp_insert_post($new_post);
        if ($post_id) {
            $exploded = explode('/', $resppurchase->data->image);

            $image_url = $resppurchase->data->image; // Define the image URL here
            $image_name = end($exploded);
            $upload_dir = wp_upload_dir(); // Set upload folder
            $image_data = file_get_contents($image_url); // Get image data
            $unique_file_name = wp_unique_filename($upload_dir['path'], $image_name); // Generate unique name
            $filename = basename($unique_file_name); // Create image file name

// Check folder permission and define file location
            if (wp_mkdir_p($upload_dir['path'])) {
                $file = $upload_dir['path'] . '/' . $filename;
            } else {
                $file = $upload_dir['basedir'] . '/' . $filename;
            }

// Create the image  file on the server
            file_put_contents($file, $image_data);

// Check image file type
            $wp_filetype = wp_check_filetype($filename, null);

// Set attachment data
            $attachment = array(
                'post_mime_type' => $wp_filetype['type'],
                'post_title' => sanitize_file_name($filename),
                'post_content' => '',
                'post_status' => 'inherit'
            );

// Create the attachment
            $attach_id = wp_insert_attachment($attachment, $file, $post_id);

// Include image.php
            require_once(ABSPATH . 'wp-admin/includes/image.php');

// Define attachment metadata
            $attach_data = wp_generate_attachment_metadata($attach_id, $file);

// Assign metadata to attachment
            wp_update_attachment_metadata($attach_id, $attach_data);

// And finally assign featured image to post
            set_post_thumbnail($post_id, $attach_id);

            ?>
            <div class="notice notice-warning is-dismissible">
                <div style="padding:12px;"><?php echo $resppurchase->message ?> <a
                            href="post.php?post=<?php echo $post_id; ?>&action=edit">View Article</a>
                </div>
                <button type="button" class="notice-dismiss"><span
                            class="screen-reader-text">Dismiss this notice.</span></button>
            </div>
            <?php

        } else {
            ?>
            <div class="notice notice-warning is-dismissible">
                <div style="padding:12px;"><?php echo $resppurchase->message ?>
                </div>
                <button type="button" class="notice-dismiss"><span
                            class="screen-reader-text">Dismiss this notice.</span></button>
            </div>
            <?php
        }
    }

    /**
     * [REQUIRED] This is the most important method
     *
     * It will get rows from database and prepare them to be showed in table
     */
    function prepare_items()
    {
        global $credits;

        $options = get_option('plume_options');

        $page = 0;
        if (isset($_REQUEST['paged'])) {
            $page = $_REQUEST['paged'];
        }
        $category = '';
        if (isset($_REQUEST['category'])) {
            $category = $_REQUEST['category'];
        }
        $term = '';
        if (isset($_REQUEST['s'])) {
            $term = urlencode($_REQUEST['s']);
        }
        $prepurchase = '';
        if (isset($_REQUEST['type'])) {
            $prepurchase = urlencode($_REQUEST['type']);
        }

        $api = new PlumeApi();
        $endpoint = 'getposts';
        $data = [
            'pag' => $page,
            'category' => $category,
            'term' => $term,
            'type' => $prepurchase,
        ];
        $response = $api->call_api($endpoint, $data);

        $per_page = 25; // constant, how much records will be shown per page
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        // here we configure table headers, defined in our methods
        $this->_column_headers = array($columns, $hidden, $sortable);

        $this->process_bulk_action();
        $total_items = 0;
        $this->items = [];
        $resp = json_decode($response, true);
        $num_pages = 0;
        if (!(isset($resp['code']) || (isset($resp['status']) && $resp['status'] == 'fail'))) {
            $credits = $resp['credits'];
            $total_items = $resp['post_count'];
            $this->items = $resp['data'];
            $num_pages = $resp['num_pages'];
        }

        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => $num_pages  // calculate pages count
        ));
    }

    function extra_tablenav($which)
    {
        $prepurchase = isset($_REQUEST['type']) && !empty($_REQUEST['type']) ? $_REQUEST['type'] : '';

        $api = new PlumeApi();
        $endpoint = 'getcategory';
        $data = [
            'type' => $prepurchase,
        ];
        $response = $api->call_api($endpoint, $data);
        $resp = json_decode($response, true);
        if (!isset($resp['code']) && $resp['status'] !== 'fail') {
            switch ($which) {
                case 'top':
                    ?>
                    <div class="alignleft actions">
                        <input type="hidden" name="type" value="<?php
                        echo isset($_REQUEST['type']) ? $_REQUEST['type'] : ''; ?>"/>
                        <select name="category" id="filter-by-category">
                            <option value="">Catégories</option>
                            <?php
                            if (!empty($resp['categories'])) {
                                foreach ($resp['categories'] as $category) {
                                    $selected = isset($_REQUEST['category']) && $category['term_id'] == $_REQUEST['category'] ? 'selected' : '';
                                    ?>
                                    <option value="<?=$category['term_id']?>" <?=$selected?>><?=$category['name']?> (<?=$category['amount']?>)</option>
                                    <?php
                                }
                            }
                            ?>
                        </select>
                        <input type="submit" id="doaction" class="button action" value="Filter">
                    </div>
                    <?php
                    break;

                case 'bottom':
                    // Your html code to output
                    break;
            }
        }
    }
}



