<?php
require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-folders.php');
require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');

class PlumePurchaseTable extends WP_List_Table
{
    /**
     * [REQUIRED] You must declare constructor and give some basic params
     */
    private $folders;

    function __construct()
    {
        global $status, $page, $credits;

        parent::__construct(array(
            'singular' => 'plumearticlepurchase',
            'plural' => 'plumearticlepurchases',
        ));
        $PlumeFolders = new PlumeFolders();
        $folders = json_decode($PlumeFolders->get_folders());
        $this->folders = isset($folders->code) || ($folders->status === 'fail') ? false : $folders;
    }

    /**
     * this is a default column renderer
     *
     * @param $item - row (key, value array)
     * @param $column_name - string (key)
     * @return HTML
     */
    public function column_default($item, $column_name)
    {
        return $item[$column_name];
    }

    public function column_poststatus($item)
    {
        if ($item['client_post_id']) {
            return sprintf(
                '<span class="plume-status-%1$s">%1$s</a>',
                get_post_status($item['client_post_id'])
            );

        } else {
            return "";
        }
    }

    public function column_title($item)
    {
        $actions = array();
        if (isset($item['folder_id']) && !empty($item['folder_id'])) {
            $actions['trash'] = sprintf(
                '<a href="javascript:void" class="removearticlefromfolder" data-id="%2$s" data-name=""%3$s"">%1$s</a>',
                sprintf(__('Retirer du dossier %s'), $item['folder_name']),
                $item['id'],
                $item['folder_name']
            );
        }
        if ($item['status'] == 'vendu' || $item['status'] == 'publish') {
            if (empty($item['permalink'])) {
                $actions['redownloadart'] = sprintf(
                    '<a href="javascript:void(0)"  data-id="%2$s" class="redownload">%1$s</a>',
                    _x('Télécharger', 'List table row action', 'wp-list-table-plume'),
                    $item['id']
                );
            } else {
                $actions['redownloadart'] = sprintf(
                    '<a href="javascript:void(0)"  data-id="%2$s" class="redownload-forbiden">%1$s</a>',
                    _x('Télécharger', 'List table row action', 'wp-list-table-plume'),
                    $item['website']
                );
            }
            $actions['examinationart'] = sprintf(
                '<a href="javascript:void"  data-id="%2$s" data-words="%3$s" class="examination">%1$s</a>',
                _x('Demande de modification', 'List table row action', 'wp-list-table-plume'),
                $item['id'],
                $item['word_count']
            );
            if ($item['client_post_id']) {
                if (get_post_status($item['client_post_id']) == "publish") {
                    $actions['voir'] = sprintf(
                        '<a href="%1$s" target="_blank">Voir</a>',
                        get_permalink($item['client_post_id'])
                    );
                }
                if (FALSE === get_post_status($item['client_post_id'])) {
                    return sprintf('%1$s %2$s',
                        $item['title'],
                        $this->row_actions($actions)
                    );
                } else {
                    if (get_post_status($item['client_post_id']) == "trash") {
                        return sprintf('%1$s %2$s',
                            $item['title'],
                            $this->row_actions($actions)
                        );
                    }
                    return sprintf('%1$s %2$s',
                        sprintf(
                            '<a href="%2$s">%1$s</a>',
                            $item['title'],
                            "post.php?post=" . $item['client_post_id'] . "&action=edit"
                        ),
                        $this->row_actions($actions)
                    );
                }
            } else {
                return sprintf('%1$s %2$s',
                    $item['title'],
                    $this->row_actions($actions)
                );
            }


        } else {
            return $item['title'];
            $this->row_actions($actions);
        }

    }

    public function column_cb($item)
    {
        $disabled = "";
        if ($item['status'] == "vendu" || $item['status'] == "publish") {
            $disabled = "";
        } else {
            $disabled = "disabled";
        }
        return sprintf(
            '<input type="checkbox" name="id[]" value="%s" ' . $disabled . '/>',
            $item['id']
        );
    }

    public function column_image($item)
    {
        return sprintf(
            '<img class="plume-img-table" src="%s" width="50px" height="50px"/>',
            $item['image']
        );
    }

    public function column_permalink($item)
    {
        if (!empty($item['permalink'])) {
            return sprintf(
                '<a href="%1$s" target="_blank" title="%2$s"><span class="plume-view-published"><img src="https://www.google.com/s2/favicons?domain=%1$s"> Publié <i class="dashicons dashicons-saved"></i></span></a>',
                $item['permalink'],
                $item['website']
            );
        }
        return '';

    }

    function column_ia($item)
    {
		if(isset($item['textbulker'] ) && $item['textbulker'] === 1){
			return '<img title="TextBulker" src="https://plume-editor.com/wp-content/uploads/2023/01/textbulker.png">';
		}
		if($item['ia'] === 1) {
			return '<img title="Optimized hybrid" src="https://plume-editor.com/wp-content/uploads/2023/01/hybride-opti-textbulker-ytg.png" width="32px">';
		}
		return '<img title="Humane" src="https://plume-editor.com/wp-content/uploads/2022/12/blogger.png">';
    }
    function column_lang($item)
    {
        $lang = empty($item['lang']) ? 'fr' : $item['lang'] ;
        return '<img src="https://plume-editor.com/wp-content/uploads/2023/01/lang-'.$lang.'-50x50.png" width="30px">';
    }

    public function column_status($item)
    {
        switch ($item['status']) {
            case "preorder-a-valider":
                return "<span class='preorderavaliderstatus'>En rédaction</span>";
            case "reserve":
                return "<span class='preorderavaliderstatus'>En rédaction</span>";
            case "vendu":
                return "<span class='vendustatus'>Disponible</span>";
            default:
                return "<span class='defaultstatus'>En attente</span>";
        }
    }

    public function get_columns()
    {
        $columns = array(
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'title' => __('Titre', 'plume'),
            'image' => __('Image', 'plume'),
            'purchasedate' => __('Date d\'achat', 'plume'),
            'word_count' => __('Mots', 'plume'),
            'ia' => __('Source', 'plume'),
            'lang' => __('Langue', 'plume'),
            'status' => __('Status', 'plume'),
            'permalink' => __('Publication', 'plume')
        );
        return $columns;
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array();
        return $sortable_columns;
    }

    public function get_bulk_actions()
    {
        $actions = array(
            'buy' => 'Télécharger'
        );
        if (!empty($this->folders)) {
            foreach ($this->folders as $folder) {
                $folder_name = ucfirst($folder->name);
                $actions["movetofolder{$folder->id}"] = "Déplacer vers <b>{$folder_name}</b>";
            }
        }
        return $actions;
    }

    public function prepare_items()
    {
        global $credits;

        $options = get_option('plume_options');

        $api = new PlumeApi();
        $endpoint = 'get_purchased_posts';
        $data = [];
        if (isset($_REQUEST['folder_id'])) {
            $data['folder_id'] = $_REQUEST['folder_id'];
        }
        $response = $api->call_api($endpoint, $data);

        $per_page = 25; // constant, how much records will be shown per page
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        // here we configure table headers, defined in our methods
        $this->_column_headers = array($columns, $hidden, $sortable);

        // [OPTIONAL] process bulk action if any
        $this->process_bulk_action();
        $resp = json_decode($response, true);
        $this->items = [];
        $total_items = 0;
        if (!isset($resp['code']) || !(isset($resp['status']) && $resp['status'] == 'fail')) {
            $total_items = count($resp);
            $this->items = $resp;
        }


        // [REQUIRED] configure pagination
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $total_items, // per page constant defined at top of method
            'total_pages' => 1 // calculate pages count
        ));
    }

    public function extra_tablenav($which)
    {
        if (false === $this->folders) return;

        switch ($which) {
            case 'top':
                echo "<div class='actions alignleft'>";
                $url = admin_url("admin.php?page=" . $_GET["page"]);
                $button_class = '';
                if (!isset($_GET['folder_id'])) {
                    $button_class = 'active';
                    $url = '#';
                }
                echo "<a href='{$url}' class='button {$button_class}' style='margin-right:5px'>Non catégorisé</a>";

                if (!empty($this->folders)) {
                    foreach ($this->folders as $folder) {
                        $nb_articles = count($folder->articles);
                        $button_class = '';
                        $url = admin_url("admin.php?page=" . $_GET["page"] . "&folder_id=" . $folder->id);
                        if (isset($_GET['folder_id']) && $_GET['folder_id'] == $folder->id) {
                            $button_class = 'active';
                            $url = '#';
                        }
                        echo "<a href='{$url}' class='button {$button_class}' style='margin-right:5px'>{$folder->name} <span class=''>({$nb_articles})</span></a>";
                    }

                }
                echo "<button id='add-plume-folder' class='button button-primary' style='margin-right:5px'>Ajouter un dossier</button>";
                if (!empty($this->folders)) {
                    echo "<button id='remove-plume-folder' class='button' style='margin-right:5px'>Supprimer un dossier</button>";
                }
                echo "</div>";
                break;

            case 'bottom':
                break;
        }
    }
}
