<?php

/**
 * Fired during plugin activation
 *
 * @link       https://plume-editor.com/
 * @since      1.0.0
 *
 * @package    Plume
 * @subpackage Plume/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Plume
 * @subpackage Plume/includes
 * @author     Plume
 */
class Plume_Activator
{

    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    protected static $instance;

    public function __construct(){
        add_action('admin_init', [$this, 'plume_redirect_on_activation']);
    }
    public static function get_instance()
    {
        if (!isset(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }
    public function plume_redirect_on_activation() {
        if (get_option('plume_do_activation_redirect', false)) {
            delete_option('plume_do_activation_redirect');
            if(!isset($_GET['activate-multi']))
            {
				wp_redirect("admin.php?page=plume-api-settings");
            }
        }
    }
    public static function activate()
    {
        add_option('plume_do_activation_redirect', true);
        $plume_options = get_option('plume_options');
        if (false === $plume_options) {
            $options = [
                'api_key' => '',
                'api_credits' => '',
                'author' => '',
                'category' => '',
            ];
            update_option('plume_options', $options);
        }

        require_once(PLUME_PLUGIN_PATH . 'admin/classes/class-plume-api.php');
        $api = new PlumeApi();
        $endpoint = 'plugin_activate';
        $data = [];
        $result = false;
        $response = $api->call_api($endpoint, $data);
        if ($response) {
            $result = json_decode($response);
        }
    }
}
