<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://plume-editor.com/
 * @since             1.0.0
 * @package           Plume
 *
 * @wordpress-plugin
 * Plugin Name:       Plume
 * Plugin URI:        https://plume-editor.com/
 * Description:       Un plugin WordPress, pour votre contenu. Ce n’est pas compliqué..
 * Version:           2.2.9
 * Author:            Plume
 * Author URI:        https://plume-editor.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       plume
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('PLUME_VERSION', '2.2.9');

if (defined('PLUMESELLER_DEV_ENV') && PLUMESELLER_DEV_ENV && defined('DEV_PLUMESELLER_API_URL') ) {
    define('PLUME_API_ENPOINT', DEV_PLUMESELLER_API_URL);
}else{
    define('PLUME_API_ENPOINT', 'https://plume-editor.com/wp-json/plume');
}

define('PLUME_API_VERSION', 4);

define(	'PLUME_PLUGIN_PATH', plugin_dir_path( __FILE__ ));
define(	'PLUME_PLUGIN_URL', plugin_dir_url( __FILE__ ));
define( 'PLUME_PLUGIN_NAME', plugin_basename(__FILE__));
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-plume-activator.php
 */
function activate_plume()
{
    require_once PLUME_PLUGIN_PATH . 'includes/class-plume-activator.php';
    Plume_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-plume-deactivator.php
 */
function deactivate_plume()
{
    require_once PLUME_PLUGIN_PATH . 'includes/class-plume-deactivator.php';
    Plume_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_plume');
register_deactivation_hook(__FILE__, 'deactivate_plume');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require PLUME_PLUGIN_PATH . 'includes/class-plume.php';
if (!class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}
require PLUME_PLUGIN_PATH . 'admin/classes/class-plume-list-table.php';
require PLUME_PLUGIN_PATH . 'admin/classes/class-plume-purchase-table.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_plume()
{

    $plugin = new Plume();
    $plugin->run();

}

run_plume();

if (!class_exists('PlumeUpdateChecker')) {

    class PlumeUpdateChecker
    {

        public $plugin_slug;
        public $version;
        public $cache_key;
        public $cache_allowed;

        public function __construct()
        {
            $this->plugin_slug = plugin_basename(__DIR__);
            $this->version = PLUME_VERSION;
            $this->cache_key = 'plume_custom_upd';
            $this->cache_allowed = false;

            add_filter('plugins_api', array($this, 'info'), 20, 3);
            add_filter('site_transient_update_plugins', array($this, 'update'));
            add_action('upgrader_process_complete', array($this, 'purge'), 10, 2);
        }

        public function request()
        {
            $remote = get_transient($this->cache_key);

            if (false === $remote || !$this->cache_allowed) {
                $remote = wp_remote_get(
                    'https://plume-editor.com/info.json',
                    array(
                        'timeout' => 10,
                        'headers' => array(
                            'Accept' => 'application/json'
                        )
                    )
                );

                if (
                    is_wp_error($remote)
                    || 200 !== wp_remote_retrieve_response_code($remote)
                    || empty(wp_remote_retrieve_body($remote))
                ) {
                    return false;
                }
                set_transient($this->cache_key, $remote, DAY_IN_SECONDS);
            }
            $remote = json_decode(wp_remote_retrieve_body($remote));
            return $remote;

        }


        function info($res, $action, $args)
        {
            // do nothing if you're not getting plugin information right now
            if ('plugin_information' !== $action) {
                return $res;
            }

            // do nothing if it is not our plugin
            if ($this->plugin_slug !== $args->slug) {
                return $res;
            }

            // get updates
            $remote = $this->request();

            if (!$remote) {
                return $res;
            }

            $res = new stdClass();

            $res->name = $remote->name;
            $res->slug = $remote->slug;
            $res->version = $remote->version;
            $res->tested = $remote->tested;
            $res->requires = $remote->requires;
            $res->author = $remote->author;
            $res->author_profile = $remote->author_profile;
            $res->download_link = $remote->download_url;
            $res->trunk = $remote->download_url;
            $res->requires_php = $remote->requires_php;
            $res->last_updated = $remote->last_updated;

            $res->sections = array(
                'description' => $remote->sections->description,
                'installation' => $remote->sections->installation,
                'changelog' => $remote->sections->changelog
            );

            if (!empty($remote->banners)) {
                $res->banners = array(
                    'low' => $remote->banners->low,
                    'high' => $remote->banners->high
                );
            }
            return $res;
        }

        public function update($transient)
        {
            if (empty($transient->checked)) {
                return $transient;
            }
            $remote = $this->request();
            if (
                $remote
                && version_compare($this->version, $remote->version, '<')
                && version_compare($remote->requires, get_bloginfo('version'), '<=')
                && version_compare($remote->requires_php, PHP_VERSION, '<')
            ) {
                $res = new stdClass();
                $res->slug = $this->plugin_slug;
                $res->plugin = plugin_basename(__FILE__);
                $res->new_version = $remote->version;
                $res->tested = $remote->tested;
                $res->package = $remote->download_url;

                $transient->response[$res->plugin] = $res;

            }
            return $transient;
        }

        public function purge($upgrader, $options)
        {
            if (
                $this->cache_allowed
                && 'update' === $options['action']
                && 'plugin' === $options['type']
            ) {
                // just clean the cache when new plugin version is installed
                delete_transient($this->cache_key);
            }
        }
    }

    new PlumeUpdateChecker();
}
